aboutsummaryrefslogtreecommitdiff
path: root/src/arch/i386/lib/c_start.S
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/i386/lib/c_start.S')
-rw-r--r--src/arch/i386/lib/c_start.S4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/arch/i386/lib/c_start.S b/src/arch/i386/lib/c_start.S
index 4c4146ec83..602fc51cbd 100644
--- a/src/arch/i386/lib/c_start.S
+++ b/src/arch/i386/lib/c_start.S
@@ -45,10 +45,10 @@ _start:
movl APIC_ID(%edi), %eax
shrl $24, %eax
/* Get the cpu index (MAX_CPUS on error) */
movl $-4, %ebx
1: addl $4, %ebx
- cmpl $(MAX_CPUS << 2), %ebx
+ cmpl $(CONFIG_MAX_CPUS << 2), %ebx
je 2
cmpl %eax, initial_apicid(%ebx)
jne 1b
@@ -45,10 +45,10 @@ _start:
movl APIC_ID(%edi), %eax
shrl $24, %eax
- /* Get the cpu index (MAX_CPUS on error) */
+ /* Get the cpu index (CONFIG_MAX_CPUS on error) */
movl $-4, %ebx
1: addl $4, %ebx